DELIMITER = ';'

# Разделитель между id подэтапа и сущностью в составном ключе очереди
REDIS_QUEUE_KEY_DELIMITER = ':'
# Ключ параметра Общий объем отправленных в РВД файлов
TOTAL_ATTACHMENTS_SIZE_KEY = 'rdm:total_attachments_size'

# Ограничение количества файлов на обработку
ATTACHMENTS_LIMIT = 500
