# Generated by Django 3.1.14 on 2024-08-19 14:24

import django.db.models.deletion
from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):

    dependencies = [
        ('edu_rdm_integration', '0010_transferredentity_export_enabled'),
    ]

    operations = [
        migrations.CreateModel(
            name='ExportingDataSubStageEntity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('entity', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='edu_rdm_integration.regionaldatamartentityenum', verbose_name='Сущность РВД')),
                ('exporting_data_sub_stage', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='edu_rdm_integration.exportingdatasubstage', verbose_name='Подэтап выгрузки данных')),
            ],
            options={
                'verbose_name': 'Связь сущности и подэтапа выгрузки',
                'verbose_name_plural': 'Связи сущности и подэтапа выгрузки',
                'db_table': 'rdm_exporting_data_sub_stage_entity',
            },
        ),
    ]
