# Generated by Django 2.2.28 on 2023-12-04 12:24
# flake8: noqa
import django.db.models.deletion
from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):

    dependencies = [
        ('edu_rdm_integration', '0004_uploaderclientlog'),
    ]

    operations = [
        migrations.CreateModel(
            name='DataMartRequestStatus',
            fields=[
                ('title', models.TextField(verbose_name='расшифровка значения')),
                ('value', models.IntegerField(verbose_name='значение')),
                ('key', models.CharField(db_index=True, max_length=512, primary_key=True, serialize=False, verbose_name='ключ')),
                ('order_number', models.PositiveIntegerField(default=100000, verbose_name='Порядковый номер')),
            ],
            options={
                'verbose_name': 'Статус загрузки данных в Витрину',
                'verbose_name_plural': 'Статусы загрузки данных в Витрину',
                'db_table': 'rdm_request_status',
            },
        ),
        migrations.AlterField(
            model_name='exportingdatasubstageuploaderclientlog',
            name='request_id',
            field=models.CharField(blank=True, db_index=True, max_length=100, verbose_name='Id запроса загрузки в витрину'),
        ),
        migrations.AddField(
            model_name='uploadstatusrequestlog',
            name='request_status',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edu_rdm_integration.DataMartRequestStatus', verbose_name='Статус запроса в витрине'),
        ),
    ]
